@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2013 ECMWF.
+ * Copyright 2005-2014 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -736,11 +736,12 @@ static int grib_fieldset_resize_int_array(grib_int_array* a,size_t newsize) {
   return err;
 }
 
-static void grib_fieldset_delete_int_array(grib_int_array* f) {
-
-  grib_context* c=f->context;
+static void grib_fieldset_delete_int_array(grib_int_array* f)
+{
+  grib_context* c = NULL;
 
   if (!f) return;
+  c = f->context;
 
   grib_context_free(c,f->el);
   grib_context_free(c,f);
